SettingsController class
Methods
addListener (GetStateUpdate listener )
→ Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId (Object ? key , GetStateUpdate listener )
→ Disposer
inherited
containsId (Object id )
→ bool
inherited
containsListener (GetStateUpdate listener )
→ bool
inherited
dispose ()
→ void
inherited
disposeId (Object id )
→ void
To dispose an id from future updates(), this ids are registered
by GetBuilder() or similar, so is a way to unlink the state change with
the Widget from the Controller.
inherited
getGptModelFromPreferences ()
→ dynamic
getLLmFromPreferences ()
→ dynamic
getLocaleFromPreferences ()
→ dynamic
getOpenAiBaseUrlFromPreferences ()
→ dynamic
getOpenAiKeyFromPreferences ()
→ dynamic
getThemeModeFromPreferences ()
→ dynamic
getUseStreamFromPreferences ()
→ dynamic
getUseWebSearchFromPreferences ()
→ dynamic
getYouCodeFromPreferences ()
→ dynamic
getYouVipFromPreferences ()
→ dynamic
initAppVersion ()
→ dynamic
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyGroupChildrens (Object id )
→ void
inherited
onClose ()
→ void
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
onDelete ()
→ void
inherited
onInit ()
→ void
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
onReady ()
→ void
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
onStart ()
→ void
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclasses.
This method should be internal and is required to define the
lifetime cycle of the subclass.
inherited
refresh ()
→ void
inherited
refreshGroup (Object id )
→ void
inherited
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
removeListenerId (Object id , VoidCallback listener )
→ void
inherited
reportAdd (VoidCallback disposer )
→ void
inherited
reportRead ()
→ void
inherited
setGptModel (String text )
→ void
setLlm (String text )
→ void
setLocale (Locale lol )
→ void
setOpenAiBaseUrl (String baseUrl )
→ void
setOpenAiKey (String text )
→ void
setThemeMode (ThemeMode model )
→ void
setUseStream (bool value )
→ void
setUseWebSearch (bool value )
→ void
setYouCode (String baseUrl )
→ void
setYouVip (bool value )
→ void
switchLocale ()
→ void
toString ()
→ String
A string representation of this object.
inherited
update ([List <Object > ? ids , bool condition = true ])
→ void
Notifies listeners to update the UI.
inherited