ConversationRepository class

Constructors

ConversationRepository()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addConversation(Conversation conversation) Future<void>
addMessage(Message message) Future<void>
deleteConversation(String uuid) Future<void>
deleteMessage(int id) Future<void>
getConversations() Future<List<Conversation>>
getMessagesByConversationUUid(String uuid) Future<List<Message>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateConversation(Conversation conversation) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited