onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() async {
await getThemeModeFromPreferences();
await getLocaleFromPreferences();
await getOpenAiBaseUrlFromPreferences();
await getOpenAiKeyFromPreferences();
await getLLmFromPreferences();
await getGptModelFromPreferences();
await getYouCodeFromPreferences();
await getUseStreamFromPreferences();
await getYouVipFromPreferences();
await initAppVersion();
super.onInit();
}